@@ -105,11 +105,19 @@ class SmappeeServiceLocation(object):
                                        name=ccc.get('value'),
                                        serialnumber=ccc.get('serialNumber'),
                                        state_values=[
-                                           {'id': 'ON_ON', 'name': 'on', 'current': False},
-                                           {'id': 'OFF_OFF', 'name': 'off', 'current': False}
+                                           {'id': 'ON_ON', 'name': 'on', 'current': ccc.get('relayStatus') is True},
+                                           {'id': 'OFF_OFF', 'name': 'off', 'current': ccc.get('relayStatus') is False}
                                        ],
                                        connection_state=ccc.get('connectionStatus').upper() if 'connectionStatus' in ccc else None,
                                        actuator_type=at)
+
+            # Load channels config pro Smappee2-series only
+            if self._device_serial_number.startswith('2'):
+                channels_config = self.smappee_api.load_channels_config()
+                for input_channel in channels_config['inputChannels']:
+                    if input_channel['inputChannelType'] == 'PRODUCTION' and input_channel['inputChannelConnection'] == 'GRID':
+                        self.has_solar_production = True
+
         else:
             # Collect service location info
             sl_info = self.smappee_api.get_service_location_info(service_location_id=self.service_location_id)
@@ -629,4 +637,3 @@ class SmappeeServiceLocation(object):
             # update appliance states
             for appliance_id, _ in self.appliances.items():
                 self.update_appliance_state(id=appliance_id)
-
